@@ -1,7 +1,7 @@
 compareGroups.fit <-
 function(X, y, Xext, selec, method, timemax, alpha, min.dis, max.ylev, max.xlev, include.label, Q1, Q3, 
          simplify, ref, ref.no, fact.ratio, ref.y, p.corrected, compute.ratio, include.miss, oddsratio.method, 
-         chisq.test.perm, byrow, chisq.test.B, chisq.test.seed, Date.format, var.equal, conf.level) {
+         chisq.test.perm, byrow, chisq.test.B, chisq.test.seed, Date.format, var.equal, conf.level, surv) {
 
    if (!is.null(Xext)){
     if (!is.matrix(Xext) & !is.data.frame(Xext))
@@ -217,9 +217,10 @@ function(X, y, Xext, selec, method, timemax, alpha, min.dis, max.ylev, max.xlev,
                             fact.ratio=fact.ratio[i], ref.y=ref.y, p.corrected=p.corrected, 
                             compute.ratio=compute.ratio, include.miss=include.miss, oddsratio.method=oddsratio.method, 
                             chisq.test.perm=chisq.test.perm, byrow=byrow, chisq.test.B=chisq.test.B, 
-                            chisq.test.seed=chisq.test.seed, Date.format=Date.format, var.equal=var.equal, conf.level=conf.level),
+                            chisq.test.seed=chisq.test.seed, Date.format=Date.format, var.equal=var.equal, 
+                            conf.level=conf.level, surv=surv),
                   silent=TRUE)
-     # if (inherits(ans.i, "try-error")) print(ans.i)
+     if (inherits(ans.i, "try-error")) print(ans.i)
      ans.i
    })
    
