@@ -9,7 +9,10 @@ library(DT, quietly=TRUE)
 library(knitr, quietly=TRUE)
 library(kableExtra, quietly=TRUE)
 
+library(shinyhelper, quietly=TRUE) #@
+
 library(shinyWidgets, quietly=TRUE)
+library(shinydashboardPlus, quietly=TRUE)
 
 
 options(shiny.maxRequestSize = 10e6) # ~10 Mb
